from flask import Blueprint, render_template, request, redirect, url_for, flash, g, session, jsonify
from models import User, Furniture
from functions import whatPicShow
from context_processors import messages_serializable

"""
Definice vsech modulu generujici stranky souvicejici se zakladnimi odkazy na webu

Moduly se nacitaji pri spusteni webu a spousti se vzdy po aktivaci nektere ze stranek odkazujici na modul zde
"""

#vytvareni listu trid
users = []
#vytvoreni zakladni tridy, ktera slouzi pro prihlaseni k dashboardu
users.append(User(id=1, username='admin', password='admin'))

#definice Blueprintu
baseRoutes = Blueprint("baseRoutes", __name__)

@baseRoutes.route('/')
def index():
    return render_template('store/store.html')

@baseRoutes.route("/about")
def about():
	return render_template('about.html')

"""
Stranky slouzici pro reklamaci zbozi, z vyplnenych informaci pomoci metod

Prototyp eshopu, ale informace nikam neuklada, protoze bychom museli resit GDPR a v nasem modelu stejne reklamace nefunguje
"""

#vytvoreni reklamace a "odeslani informaci pro eshop"
@baseRoutes.route("/reklamace", methods=['GET', 'POST'])
def reklamace():
    furnitures = Furniture.query.order_by(Furniture.name)
    if request.method == 'POST':
        email = request.form.get('email')
        telefon = request.form.get('tel')
        order = request.form.get('id_Order')
        name = request.form.get('name_product')
        spec = request.form.get('spec')
        return redirect(url_for("baseRoutes.reklamaceDone", email_product=email, telefon_product = telefon, order_product = order, 
                                name_product = name, spec_product = spec ))
    return render_template('reklamace.html', furnitures=furnitures)

#souhrn reklamace
@baseRoutes.route("/reklamace/done", methods=['GET', 'POST'])
def reklamaceDone():
    email_product = request.args.get('email_product', None)
    telefon_product = request.args.get('telefon_product', None)
    order_product = request.args.get('order_product', None)
    name_product = request.args.get('name_product', None)
    spec_product = request.args.get('spec_product', None)
    furnitures = Furniture.query.order_by(Furniture.name)
    return render_template('reklamaceDone.html', furnitures=furnitures, email = email_product, telefon = telefon_product, 
                           name = name_product, order = order_product, spec = spec_product)

#stranka s kontaktem
@baseRoutes.route("/kontakt")
def kontakt():
	return render_template('kontakt.html')

#stranka, kde po zadani urciteho hesla muze uzivatel vyhledat jednotlive kategorie/polozky
@baseRoutes.route('/search', methods=['GET', 'POST'])
#specialni cesta pro chatbota k doporucovani nabytku
@baseRoutes.route('/store/search/<string:special_search>', methods=['GET', 'POST'])
def search(special_search = ""):
    furnitures = Furniture.query.order_by(Furniture.name)
    furniturePics = whatPicShow(furnitures)
    warning = True
    if request.method == 'POST':
        search = request.form.get('search')

    elif special_search != "":
        search = special_search
        warning = False

    return render_template('search.html', search_text = search, furnitures = furnitures, pics = furniturePics, warning_mess = warning )

#modul pro registraci noveho zakaznika, vyuiva metodu post pro ziskani informaci s formulare
@baseRoutes.route("/register", methods=['GET', 'POST'])
def register():
    if request.method == 'POST':
        password = request.form['password1']
        passwordagain = request.form['password2']
        if password == passwordagain:
            return redirect(url_for('baseRoutes.registerDone'))
        else:
            flash("Passwords are not the same!")
    return render_template('login/register.html')

@baseRoutes.route("/registerdone")
def registerDone():
    return render_template('login/registerDone.html')

#modul pro zalogovani noveho zakaznika
@baseRoutes.route("/login", methods=['GET', 'POST'])
def login():
    g.user = None

    #overeni zda je uzivatel uz prihlasen
    if 'user_id' in session:
        user = [x for x in users if x.id == session['user_id']][0]
        g.user = user

    #pokud ne, tak vyuziti metody post pro ziskani informaci z formulare
    if not g.user:

        if request.method == 'POST':
            session.pop('user_id', None)

            username = request.form['username']
            password = request.form['password']
        
            #kdyz souhlasi prihlasovaci udaje, tak se uzivatel dostane do dashboardu
            if username == 'admin':
                user = [x for x in users if x.username == username][0]
                if user and user.password == password:
                    session['user_id'] = user.id
                    return redirect(url_for('dashRoutes.dashboard'))
            #jinak se ukaze message
            flash("Spatne prihlasovaci udaje!")
            return redirect(url_for('baseRoutes.login'))

        return render_template('login/login.html')

    #pokud ano, tak automaticke presmerovani na dashboard
    else:
        return redirect(url_for('dashRoutes.dashboard'))

@baseRoutes.route('/forgottenpw')
def forgottenpw():
    return render_template('login/forgottenPW.html')

#stranka pro uzivatele chtejici si nechat navrhnout mistnost
@baseRoutes.route('/design')
def design():
    return render_template('design.html')

#specialni odkaz pro javascript, ve kterem se pracuje s json dictionaries nasich zprav pro chatbota 
@baseRoutes.route('/chatbot')
def chatbot():
    messages_data = messages_serializable()
    return jsonify(messages_data)
