from flask import Blueprint, render_template, request, redirect, url_for, g, session
from dbCreater import db
from models import Furniture, Chatbot_message, User_message
from baseRoutes import users
from functions import newFurniture, checkingTypeFurniture, botMessage, userMessage, checkID

"""
Definice vsech modulu generujici stranky souvicejici s dashboardem - tedy cestou /dashboard

Moduly se nacitaji pri spusteni webu a spousti se vzdy po aktivaci nektere ze stranek odkazujici na modul zde
"""

#definice Blueprintu
dashRoutes = Blueprint("dashRoutes", __name__)

#definice modulu pred kazdym volanim modulu v dashboardu, slouzi k vyskoceni z dashboardu pokud neni uzivatel prihlasen
def before_request():
    g.user = None

    if 'user_id' in session:
        user = [x for x in users if x.id == session['user_id']][0]
        g.user = user

dashRoutes.before_request(before_request)

#zakladni stranka dashboardu s moznosti pridani/aktualizaci/smazani produktu
@dashRoutes.route("/", methods=['GET', 'POST'])
def dashboard():
    if not g.user:
        return redirect(url_for('baseRoutes.login'))
    else:
        if request.method == 'POST':
            myFurniture = newFurniture(request.form['name'], request.form['type_furniture'], request.form['color'],
                            request.form['price'], request.form['desc'], request.form['sale'], request.form['stored'])
            
            checkingTypeFurniture(myFurniture, 'create')

        furnitures = Furniture.query.order_by(Furniture.date_created)
        return render_template('dashboard/dashboard.html', furnitures=furnitures)

#definice modulu pro aktualizaci produktu z databaze pomoci post metody
@dashRoutes.route("/update/<int:id>", methods=['GET', 'POST'])
def update(id):

    #volani nabytku z databaze dle ID
    furnitureData = Furniture.query.get_or_404(id)
    if request.method == "POST":
        furnitureData.name = request.form['name']
        furnitureData.type_furniture =  request.form['type_furniture']
        furnitureData.color = request.form['color']
        furnitureData.price = request.form['price']
        furnitureData.desc = request.form['desc']
        furnitureData.sale = request.form['sale']
        furnitureData.stored = request.form['stored']

        #kontrola spravneho typu
        if checkingTypeFurniture(furnitureData, 'change') == None:
            return redirect(url_for('dashRoutes.update', id = furnitureData.id ))
        else:
            return redirect('/dashboard')

    return render_template('dashboard/update.html', furniture=furnitureData)

#definice modulu pro odstraneni daneho nabytku z databaze
@dashRoutes.route("/delete/<int:id>", methods=['GET', 'POST'])
def delete(id):
    furniture_to_delete = Furniture.query.get_or_404(id)

    try:
        db.session.delete(furniture_to_delete)
        db.session.commit()
        return redirect('/dashboard')
    except:
        return "There was an error with deleting furniture"

#definice modulu pro praci se zpravami v chatbotovi a jejim zobrazenim
@dashRoutes.route("/chatbot", methods=['GET', 'POST'])
def chatbotMod():    

    if request.method == 'POST':
        if request.form['add'] == 'Ulozit zpravu chatbota':
            newMessageBot = botMessage(request.form['name'], request.form['message_bot'], request.form['link'])
            db.session.add(newMessageBot)
            db.session.commit()
            return redirect('/dashboard/chatbot')

        elif request.form['add'] == 'Ulozit zpravu uzivatele':
            newMessageUser = userMessage(request.form['message_user'], request.form['answer_ID'], request.form['prev_ID'])
            if newMessageUser == None:
                return redirect('/dashboard/chatbot')
            db.session.add(newMessageUser)
            db.session.commit()
            return redirect('/dashboard/chatbot')

    chatbot_mess = Chatbot_message.query.order_by(Chatbot_message.id)
    user_mess = User_message.query.order_by(User_message.id)
    return render_template('dashboard/chatbotMod.html', chatbot_mess = chatbot_mess, user_mess = user_mess)

#definice modulu pro odstraneni dane zpravy z databaze chatbota
@dashRoutes.route("/chatbot/delete/<int:id>")
def chatbot_mess_delete(id):
    chatbot_mess_to_delete = Chatbot_message.query.get_or_404(id)

    try:
        db.session.delete(chatbot_mess_to_delete)
        db.session.commit()
        return redirect('/dashboard/chatbot')
    except:
        return "There was an error with deleting furniture"

#definice modulu pro odstraneni dane zpravy z databaze uzivatele
@dashRoutes.route("/user/delete/<int:id>")
def user_mess_delete(id):
    user_mess_to_delete = User_message.query.get_or_404(id)

    try:
        db.session.delete(user_mess_to_delete)
        db.session.commit()
        return redirect('/dashboard/chatbot')
    except:
        return "There was an error with deleting furniture"


#definice modulu pro aktualizaci zprav chatbota v databazi pomoci post metody
@dashRoutes.route("/chatbot/update/<int:id>", methods=['GET', 'POST'])
def chatbot_mess_update(id):
    messData = Chatbot_message.query.get_or_404(id)
    if request.method == "POST":
        messData.name = request.form['name']
        messData.message =  request.form['message_bot']
        messData.reference = request.form['link']
        db.session.commit()
        return redirect('/dashboard/chatbot')

    return render_template('dashboard/chatbotUpdate.html', chatbot_mess = messData)

#definice modulu pro aktualizaci zprav uzivatele v databazi pomoci post metody
@dashRoutes.route("/user/update/<int:id>", methods=['GET', 'POST'])
def user_mess_update(id):
    messData = User_message.query.get_or_404(id)
    if request.method == "POST":
        messData.message =  request.form['message_user']
        messData.answer_id =  request.form['answer_ID']
        messData.chatbot_message_id =  request.form['prev_ID']
        checked = checkID (messData.answer_id, messData.chatbot_message_id)
        if checked == True:
            db.session.commit()
            return redirect('/dashboard/chatbot')
        else:
            return redirect(url_for('dashRoutes.user_mess_update', id = messData.id ))
    return render_template('dashboard/userUpdate.html', user_mess = messData)