from flask import Blueprint, render_template, redirect, flash, request, url_for
from functions import whatPicShow, sortedFurn, addProduct
from dbCreater import db
from models import Cart

"""
Definice vsech modulu generujici stranky souvicejici s katalogem polozek - tedy cestou /store

Moduly se nacitaji pri spusteni webu a spousti se vzdy po aktivaci nektere ze stranek odkazujici na modul zde
"""

#definice Blueprintu
storeRoutes = Blueprint("storeRoutes", __name__)


#jednotlive moduly odesilaji vzdy html strance, setridene produkty a pole odkazu na obrazky v souborech
@storeRoutes.route('/', methods=['GET', 'POST'])
#specialni cesta pro serazovani katalogu
@storeRoutes.route('/sort/<string:sorting>', methods=['GET', 'POST'])
def store(sorting=None):
    furnitures = sortedFurn(sorting)
    furniturePics = whatPicShow(furnitures)
    if request.method == "POST":
        color_filtered = request.form.getlist('color')
        price_max = request.form.get('price')
        only_stored = request.form.get('stored')

    else:
        color_filtered = ['bila', 'cerna', 'hneda', 'modra' , 'oranzova', 'seda']
        price_max = 100000
        only_stored = None

    return render_template('store/store.html', furnitures=furnitures, pics=furniturePics, colors = color_filtered, price = price_max, stored = only_stored, sort = sorting)

#detail produktu
@storeRoutes.route("/<int:id>")
def product(id):
    furnitures = sortedFurn(None)
    furniturePics = whatPicShow(furnitures)
    return render_template('store/product.html', furnitures=furnitures, id=id, pics=furniturePics)

#jednotlive kategorie produktu, se specialnimi cestami pouzite pro chatbota
@storeRoutes.route('/<string:type_furn>', methods=['GET', 'POST'])
@storeRoutes.route('/<string:type_furn>/<string:sorting>', methods=['GET', 'POST'])
@storeRoutes.route('/<string:type_furn>/<string:sorting>/<string:color>/<int:price>', methods=['GET', 'POST'])
def productsFiltered(type_furn, sorting = None, color = "all", price = 0):
    furnitures = sortedFurn(sorting)
    furniturePics = whatPicShow(furnitures)
    if request.method == "POST":
        color_filtered = request.form.getlist('color')
        price_max = request.form.get('price')
        only_stored = request.form.get('stored')

    else:
        if color != "all":
            color_filtered = [color]
        else:
            color_filtered = ['modra', 'cerna', 'bila', 'oranzova', 'hneda', 'seda']

        if price != 0:
            price_max = price
        else:
            price_max = 100000

        only_stored = None

    return render_template('store/productsFilter.html', furnitures=furnitures, pics=furniturePics, type = type_furn, colors = color_filtered, price = price_max, stored = only_stored, sort = sorting)

"""
Moduly souvisejici s kosikem, ktere se zapisuji do databaze - ukladaji se informace o tom, co v kosiku je

Pro jednoduchost prototypu neni v reseni pocitano s vice zakaznikama, a tak vsichni budou mit pristup ke stejnemu kosiku
"""

#pridavani noveho produktu do kosiku - neobsahuje html stranku a zakaznika nechava na stejne strance
@storeRoutes.route('/cart/<int:id>', methods=['GET', 'POST'])
def addCart(id):
    new_product = addProduct(id)
    if new_product == None:
        flash("Chyba pri pridavani polozky do kosiku.")
        return redirect('/store/'+str(id))
    db.session.add(new_product)
    db.session.commit()
    
    return redirect(request.referrer)

#smazani produktu z kosiku - neobsahuje html stranku a zakaznika nechava na stejne strance
@storeRoutes.route('/cart/delete/<int:id>')
@storeRoutes.route('/cart/delete/<int:id>/<string:how_many>')
def deleteCart(id, how_many=None):
    product_to_delete = Cart.query.get_or_404(id)
    if how_many == None:
        try:
            db.session.delete(product_to_delete)
            db.session.commit()
            return redirect(request.referrer)
        except:
            return "There was an error with deleting furniture"
    else:
        try:
            #smazani vsech produktu se stejnym ID
            products_by_id = Cart.query.filter_by(id_product=product_to_delete.id_product).all()
            for product in products_by_id:
                db.session.delete(product)
                db.session.commit()
            return redirect(request.referrer)
        except:
            return "There was an error with deleting furniture"


    
#stranka vypisu vsech produktu v kosiku
@storeRoutes.route('/cart', methods=['GET', 'POST'])
def cart():
    products = Cart.query.order_by((Cart.id_product))
    furnitures = sortedFurn(None)
    furniturePics = whatPicShow(furnitures)

    array_products = [0] * products.count()
    for x, product in enumerate(products):
        array_products[x-1] = product.id_product

    return render_template('cart/cart.html', products = products, furnitures = furnitures, pics = furniturePics, array_ids = array_products)

#stranka vyberu dopravy
@storeRoutes.route('/cart/delivery')
def cartDelivery():
    return render_template('cart/cartDelivery.html')

#stranka k vyplneni zakladnich informaci pro vyzvednuti v obchode
@storeRoutes.route('/cart/instore', methods=['GET', 'POST'])
def cartInstore():
    if request.method == 'POST':
        first = request.form.get('firstname')
        second = request.form.get('secondname')
        email = request.form.get('email')
        telefon = request.form.get('tel')
        
        return redirect(url_for("storeRoutes.cartInstoreDone", first_name = first, second_name = second, email_delivery = email, telefon_delivery = telefon ))

    return render_template('cart/cartInstore.html')

#souhrn informaci k nakupu a vyzvednuti v obchode
@storeRoutes.route("/cart/instore/done", methods=['GET', 'POST'])
def cartInstoreDone():
    first_name = request.args.get('first_name', None)
    second_name = request.args.get('second_name', None)
    email_delivery = request.args.get('email_delivery', None)
    telefon_delivery = request.args.get('telefon_delivery', None)
    products = Cart.query.order_by((Cart.id_product))
    furnitures = sortedFurn(None)
    furniturePics = whatPicShow(furnitures)

    array_products = [0] * products.count()
    for x, product in enumerate(products):
        array_products[x-1] = product.id_product

    return render_template('cart/cartInstoreDone.html', array_ids = array_products, pics = furniturePics, furnitures = furnitures, products = products, 
                           email = email_delivery, telefon = telefon_delivery, first = first_name, second = second_name)

#stranka k vyplneni vsech informaci pro doruceni domu
@storeRoutes.route('/cart/adress', methods=['GET', 'POST'])
def cartAdress():
    if request.method == 'POST':
        first = request.form.get('firstname')
        second = request.form.get('secondname')
        street = request.form.get('street')
        city = request.form.get('city')
        psc = request.form.get('psc')
        detail = request.form.get('detail')
        email = request.form.get('email')
        telefon = request.form.get('tel')
        company = request.form.get('company')
        ico = request.form.get('ico')
        dic = request.form.get('dic')
        pay = request.form.get('pay')
        
        return redirect(url_for("storeRoutes.cartAdressDone", first_name = first, second_name = second, email_delivery = email, telefon_delivery = telefon, 
                                street_delivery = street, city_delivery = city, psc_delivery = psc, detail_delivery = detail, company_delivery = company, ico_delivery = ico,
                               dic_delivery = dic, pay_delivery = pay))

    return render_template('cart/cartAdress.html')

#souhrn informaci k nakupu a doruceni domu
@storeRoutes.route("/cart/adress/done", methods=['GET', 'POST'])
def cartAdressDone():
    first_name = request.args.get('first_name', None)
    second_name = request.args.get('second_name', None)
    email_delivery = request.args.get('email_delivery', None)
    telefon_delivery = request.args.get('telefon_delivery', None)
    street_delivery = request.args.get('street_delivery', None)
    city_delivery = request.args.get('city_delivery', None)
    psc_delivery = request.args.get('psc_delivery', None)
    detail_delivery = request.args.get('detail_delivery', None)
    company_delivery = request.args.get('company_delivery', None)
    ico_delivery = request.args.get('ico_delivery', None)
    dic_delivery = request.args.get('dic_delivery', None)
    pay_delivery = request.args.get('pay_delivery', None)
    products = Cart.query.order_by((Cart.id_product))
    furnitures = sortedFurn(None)
    furniturePics = whatPicShow(furnitures)

    array_products = [0] * products.count()
    for x, product in enumerate(products):
        array_products[x-1] = product.id_product

    return render_template('cart/cartAdressDone.html', array_ids = array_products, pics = furniturePics, furnitures = furnitures, products = products, 
                           email = email_delivery, telefon = telefon_delivery, first = first_name, second = second_name, street = street_delivery, 
                           city = city_delivery, psc = psc_delivery, detail = detail_delivery, company = company_delivery, ico = ico_delivery, dic = dic_delivery,
                           pay = pay_delivery )

#uspesne vytvoreni objednavky a prechod zpatky do obchodu
@storeRoutes.route('/cart/approved')
def cartAproved():
    flash("Objednavka vytvorena")
    return redirect(url_for('storeRoutes.store'))